@@ -387,13 +387,58 @@ class RepaidPaymentAdvanceTransactionDTO(BaseTransactionDTO):
                                                   attributes["amount"], attributes["balance"], attributes["summary"],
                                                   attributes.get("tags"), relationships)
 
+class RewardTransactionDTO(BaseTransactionDTO):
+    def __init__(self, id: str, created_at: datetime, direction: str, amount: int, balance: int, summary: str,
+                 receiver_counterparty: Counterparty, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
+        BaseTransactionDTO.__init__(self, id, created_at, direction, amount, balance, summary, tags, relationships)
+        self.type = 'rewardTransaction'
+        self.attributes["receiverCounterparty"] = receiver_counterparty
+
+    @staticmethod
+    def from_json_api(_id, _type, attributes, relationships):
+        return RewardTransactionDTO(_id, date_utils.to_datetime(attributes["createdAt"]), attributes["direction"],
+                                    attributes["amount"], attributes["balance"], attributes["summary"],
+                                    Counterparty.from_json_api(attributes.get("receiverCounterparty")),
+                                    attributes.get("tags"), relationships)
+
+
+class PaymentCanceledTransactionDTO(BaseTransactionDTO):
+    def __init__(self, id: str, created_at: datetime, direction: str, amount: int, balance: int, summary: str,
+                 tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
+        BaseTransactionDTO.__init__(self, id, created_at, direction, amount, balance, summary, tags, relationships)
+        self.type = 'paymentCanceledTransaction'
+
+    @staticmethod
+    def from_json_api(_id, _type, attributes, relationships):
+        return PaymentCanceledTransactionDTO(_id, date_utils.to_datetime(attributes["createdAt"]),
+                                             attributes["direction"], attributes["amount"], attributes["balance"],
+                                             attributes["summary"], attributes.get("tags"), relationships)
+
+class ChargebackTransactionDTO(BaseTransactionDTO):
+    def __init__(self, id: str, created_at: datetime, direction: str, amount: int, balance: int, summary: str,
+                 counterparty: Counterparty, tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
+        BaseTransactionDTO.__init__(self, id, created_at, direction, amount, balance, summary, tags, relationships)
+        self.type = 'chargebackTransaction'
+        self.attributes["counterparty"] = counterparty
+
+    @staticmethod
+    def from_json_api(_id, _type, attributes, relationships):
+        return ChargebackTransactionDTO(_id, date_utils.to_datetime(attributes["createdAt"]),
+                                        attributes["direction"], attributes["amount"], attributes["balance"],
+                                        attributes["summary"],
+                                        Counterparty.from_json_api(attributes.get("counterparty")),
+                                        attributes.get("tags"), relationships)
+
 TransactionDTO = Union[OriginatedAchTransactionDTO, ReceivedAchTransactionDTO, ReturnedAchTransactionDTO,
                        ReturnedReceivedAchTransactionDTO, DishonoredAchTransactionDTO, BookTransactionDTO,
                        PurchaseTransactionDTO, AtmTransactionDTO, FeeTransactionDTO, CardTransactionDTO,
                        CardReversalTransactionDTO, WireTransactionDTO, ReleaseTransactionDTO, AdjustmentTransactionDTO,
                        InterestTransactionDTO, DisputeTransactionDTO, CheckDepositTransactionDTO,
                        ReturnedCheckDepositTransactionDTO, PaymentAdvanceTransactionDTO,
-                       RepaidPaymentAdvanceTransactionDTO]
+                       RepaidPaymentAdvanceTransactionDTO, RewardTransactionDTO, PaymentCanceledTransactionDTO,
+                       ChargebackTransactionDTO]
 
 
 class PatchTransactionRequest(BaseTransactionDTO, UnitRequest):
